@@ -1,6 +1,6 @@
 package MediaWiki::DumpFile::Pages;
 
-our $VERSION = '0.1.2';
+our $VERSION = '0.1.3_01';
 
 use strict;
 use warnings;
@@ -51,6 +51,10 @@ sub next {
 	return MediaWiki::DumpFile::Pages::Page->new($new, $version);
 }
 
+sub current_byte {
+	return $_[0]->{xml}->reader->byteConsumed;
+}
+
 sub version {
 	return $_[0]->{version};
 }
